@@ -27,6 +27,9 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
 
@@ -38,4 +41,3 @@ dbm_close (dbf)
 {
   gdbm_close (dbf);
 }
-
